@@ -29,13 +29,14 @@ SOFTWARE.
 
 
 import re
+import time
 
 from bs4 import BeautifulSoup
 import requests
 
 
 BASE_URL = 'https://news.ycombinator.com'
-
+INTERVAL_BETWEEN_REQUESTS = 1 # seconds to sleep between 2 consecutive page requests
 
 class HN(object):
     """
@@ -43,6 +44,41 @@ class HN(object):
     """
 
 
+    def _get_next_page(self, soup):
+        """
+        Get the relative url of the next page (The "More" link at
+        the bottom of the page)
+        """
+        table = soup.findChildren('table')[2] # the table with all submissions
+        
+        # the last row of the table contains the relative url of the next page
+        return table.findChildren(['tr'])[-1].find('a').get('href')
+
+
+    def _get_soups(self, page, page_limit=1):
+        """
+        Returns a list of soups bs4 objects for all pages in the chain starting
+        from 'page' following up to page_limit links.
+        \tpage_limit=1 implies just the top level page
+        """
+        soups = list() # will hold all soups
+        soups.append(self._get_soup(page)) # get the first page
+
+        while len(soups) < page_limit:
+            # get as manu pages as requested
+            cur_soup = soups[-1] # get the last seen page's soup
+            time.sleep(INTERVAL_BETWEEN_REQUESTS) # be a good citizen
+            next_page = self._get_next_page(cur_soup).lstrip('//')
+            next_soup = self._get_soup(next_page) # get the next soup
+            if len(next_soup.findChildren('table')) != 0:
+                # making sure we are on the right page... get it?
+                soups.append(next_soup)
+            else:
+                break
+            
+        return soups
+
+
     def _get_soup(self, page=''):
         """
         Returns a bs4 object of the page requested
@@ -59,13 +95,16 @@ class HN(object):
         table = soup.findChildren('table')[2] # the table with all submissions
         rows = table.findChildren(['tr'])[:-2] # get all rows but last 2
         # remove the spacing rows
-        spacing = xrange(2, len(rows), 3) # indices of spacing tr's
+        try:
+            spacing = xrange(2, len(rows), 3) # indices of spacing tr's
+        except:
+            spacing = range(2, len(rows), 3) # indices of spacing tr's python3
         rows = [row for (i, row) in enumerate(rows) if (i not in spacing)]
         # rank, title, domain
         info = [row for (i, row) in enumerate(rows) if (i % 2 == 0)]
         # points, submitter, comments
         detail = [row for (i, row) in enumerate(rows) if (i % 2 != 0)]
-
+        
         return zip(info, detail) # build a list of tuple for all post
 
 
@@ -116,16 +155,16 @@ class HN(object):
                     num_comments = 0
             else: # this is a job post
                 points = 0
-                submitter = None
-                submitter_profile = None
-                published_time = detail_concern[0]
-                comment_tag = None
+                submitter = ''
+                submitter_profile = ''
+                published_time = unicode(detail_concern[0])
+                comment_tag = ''
                 try:
                     story_id = int(re.match(r'.*=(\d+)', link).groups()[0])
                 except AttributeError:
-                    story_id = None # job listing that points to external link
-                comments_link = None
-                comment_count = 0
+                    story_id = -1 # job listing that points to external link
+                comments_link = ''
+                comment_count = -1
             #-- Get the detail about a story --#
 
             story = {
@@ -144,17 +183,25 @@ class HN(object):
 
             }
             all_stories.append(story)
-
+        
         return all_stories
 
 
-    def get_stories(self, story_type=''):
+    def get_stories(self, story_type='', page_limit=1):
         """
         Returns a list of stories from the passed page
         of HN. 'story_type' can be:
-        '' = top stories (homepage)
-        'newest' = most recent stories
-        'best' = best stories
+        \t'' = top stories (homepage)
+        \t'newest' = most recent stories
+        \t'best' = best stories
+
+        'page_limit' specifies the maximum number of pages to get.
+        \tpage_limit=1 implies just the top level page
         """
-        all_rows = self._get_zipped_rows(self._get_soup(page=story_type))
-        return self._build_story(all_rows)
+        story = list()
+        all_soups = self._get_soups(story_type, page_limit)
+        for soup in all_soups:
+            all_rows = self._get_zipped_rows(soup)
+            story = story + self._build_story(all_rows)
+
+        return story
\ No newline at end of file
